Welcome to telegram-upload's documentation!
===========================================
Telegram-upload uses your personal Telegram account to upload and download files up to 2GiB (bots are limited to 50
MiB). Turn Telegram into your personal cloud!


To **install** telegram-upload, run this command in your terminal:

.. code-block:: console

    $ pip install -U telegram-upload


Contents
--------

.. toctree::
   :maxdepth: 2
   :glob:

   installation
   readme
   usage
   troubleshooting
   contributing
   authors
   history


..
   _ modules
